@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import ast
-from asttokens.asttokens import ASTTokens
+from typing import Union
 
 
 def extract_text_range(source, text_range):
@@ -19,8 +19,8 @@ def extract_text_range(source, text_range):
     return "".join(lines)
 
 
-def find_expression(node, text_range):
-    for node in ast.walk(node):
+def find_expression(start_node, text_range):
+    for node in ast.walk(start_node):
         if (
             isinstance(node, ast.expr)
             and node.lineno == text_range.lineno
@@ -30,6 +30,8 @@ def find_expression(node, text_range):
         ):
             return node
 
+    return None
+
 
 def parse_source(source: bytes, filename="<unknown>", mode="exec", fallback_to_one_char=False):
     root = ast.parse(source, filename, mode)
@@ -167,13 +169,18 @@ def get_last_child(node, skip_incorrect=True):
     return None
 
 
-def mark_text_ranges(node, source: bytes, fallback_to_one_char=False):
+def mark_text_ranges(node, source: Union[bytes, str], fallback_to_one_char=False):
     """
     Node is an AST, source is corresponding source as string.
     Function adds recursively attributes end_lineno and end_col_offset to each node
     which has attributes lineno and col_offset.
     """
-    ASTTokens(source.decode("utf8"), tree=node)
+    from asttokens.asttokens import ASTTokens
+
+    if isinstance(source, bytes):
+        source = source.decode("utf8")
+
+    ASTTokens(source, tree=node)
     for child in ast.walk(node):
         if hasattr(child, "last_token"):
             child.end_lineno, child.end_col_offset = child.last_token.end
