@@ -100,6 +100,9 @@ class SyntaxText(EnhancedText):
     def is_python_text(self):
         return self.file_type == "python"
 
+    def is_pythonlike_text(self):
+        return self.file_type == "pythonlike"
+
     def update_tabs(self):
         tab_chars = 4
         tab_pixels = tk.font.nametofont(self["font"]).measure("n" * tab_chars)
@@ -209,6 +212,9 @@ class CodeView(tktextext.EnhancedTextFrame):
     def get_content_as_bytes(self):
         content = self.get_content()
 
+        for callback in get_workbench().iter_save_hooks():
+            content = callback(self, content=content)
+
         # convert all linebreaks to original format
         content = OLD_MAC_LINEBREAK.sub(self._original_newlines, content)
         content = WINDOWS_LINEBREAK.sub(self._original_newlines, content)
@@ -252,6 +258,9 @@ class CodeView(tktextext.EnhancedTextFrame):
     def set_content(self, content, keep_undo=False):
         content, self._original_newlines = tweak_newlines(content)
 
+        for callback in get_workbench().iter_load_hooks():
+            content = callback(self, content=content)
+
         self.text.direct_delete("1.0", tk.END)
         self.text.direct_insert("1.0", content)
 
