@@ -3,21 +3,20 @@
 """
 Classes used both by front-end and back-end
 """
+import ast
 import logging
 import os.path
 import platform
 import site
 import subprocess
 import sys
-import traceback
 from collections import namedtuple
-from threading import Thread
 from typing import List, Optional, Dict, Iterable, Tuple  # @UnusedImport
 
 logger = logging.getLogger(__name__)
 
 MESSAGE_MARKER = "\x02"
-OBJECT_LINK_START = "[object_link_for_thonny]"
+OBJECT_LINK_START = "[object_link_for_thonny=%d]"
 OBJECT_LINK_END = "[/object_link_for_thonny]"
 
 IGNORED_FILES_AND_DIRS = [
@@ -305,6 +304,24 @@ def get_exe_dirs():
     if os.path.dirname(sys.executable) not in result:
         result.append(os.path.dirname(sys.executable))
 
+    # These entries are used by Anaconda
+    for part in [
+        "Library/mingw-w64/bin",
+        "Library/usr/bin",
+        "Library/bin",
+        "Scripts",
+        "bin",
+        "condabin",
+    ]:
+        dirpath = os.path.join(sys.prefix, part.replace("/", os.sep))
+        if os.path.isdir(dirpath) and dirpath not in result:
+            result.append(dirpath)
+
+    if platform.system() != "Windows" and "/usr/local/bin" not in result:
+        # May be missing on macOS, when started as bundle
+        # (yes, more may be missing, but this one is most useful)
+        result.append("/usr/local/bin")
+
     return result
 
 
@@ -638,6 +655,28 @@ def get_python_version_string(version_info: Optional[Tuple] = None, maxsize=None
     return result
 
 
+def try_load_modules_with_frontend_sys_path(module_names):
+    try:
+        frontend_sys_path = ast.literal_eval(os.environ["THONNY_FRONTEND_SYS_PATH"])
+        assert isinstance(frontend_sys_path, list)
+    except Exception as e:
+        logger.warning("Could not get THONNY_FRONTEND_SYS_PATH", exc_info=e)
+        return
+
+    from importlib import import_module
+
+    old_sys_path = sys.path.copy()
+    sys.path = sys.path + frontend_sys_path
+    try:
+        for name in module_names:
+            try:
+                import_module(name)
+            except ImportError:
+                pass
+    finally:
+        sys.path = old_sys_path
+
+
 class ConnectionFailedException(Exception):
     pass
 
