@@ -3,15 +3,18 @@
 import ast
 import configparser
 import datetime
+import logging
 import os.path
 import sys
 import tkinter as tk
-import traceback
 from configparser import ConfigParser
 from logging import exception
 
 from thonny import THONNY_USER_DIR
 
+
+logger = logging.getLogger(__name__)
+
 _manager_cache = {}
 
 
@@ -77,8 +80,8 @@ class ConfigurationManager:
                             import shutil
 
                             shutil.copytree(old_user_logs, new_user_logs)
-                        except Exception:
-                            traceback.print_exc()
+                        except Exception as e:
+                            logger.exception("Problem migrating user logs", exc_info=e)
 
         if not self.get_option("general.configuration_creation_timestamp"):
             self.set_option(
@@ -112,8 +115,10 @@ class ConfigurationManager:
             val = self._ini.get(section, option)
 
             # if option's data type is str (inferred from the default value)
-            # then don't try to parse anything
-            if isinstance(self._defaults.get(name), str):
+            # then don't try to parse anything (unless it's None)
+            if val == "None":
+                return None
+            elif isinstance(self._defaults.get(name), str):
                 return val
             else:
                 return self._parse_value(val)
