@@ -28,6 +28,8 @@ from thonny.ui_utils import askopenfilename, asksaveasfilename, select_sequence
 _dialog_filetypes = [("Python files", ".py .pyw .pyi"), ("all files", ".*")]
 
 REMOTE_PATH_MARKER = " :: "
+PYTHON_EXTENSIONS = {"py", "pyw", "pyi"}
+PYTHONLIKE_EXTENSIONS = set()
 
 logger = logging.getLogger(__name__)
 
@@ -314,8 +316,10 @@ class Editor(ttk.Frame):
             self._code_view.set_file_type(None)
         else:
             ext = self._filename.split(".")[-1].lower()
-            if ext in ["py", "pyw", "pyi"]:
+            if ext in PYTHON_EXTENSIONS:
                 file_type = "python"
+            elif ext in PYTHONLIKE_EXTENSIONS:
+                file_type = "pythonlike"
             else:
                 file_type = None
 
@@ -506,6 +510,9 @@ class Editor(ttk.Frame):
         get_workbench().unbind("DebuggerResponse", self._listen_debugger_progress)
         get_workbench().unbind("ToplevelResponse", self._listen_for_toplevel_response)
         ttk.Frame.destroy(self)
+        get_workbench().event_generate(
+            "EditorTextDestroyed", editor=self, text_widget=self.get_text_widget()
+        )
 
 
 class EditorNotebook(ui_utils.ClosableNotebook):
