@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 BASE_LANGUAGE_CODE = "en_US"
 BASE_LANGUAGE_NAME = "English"
 
-# http://www.internationalphoneticalphabet.org/languages/language-names-in-native-language/
+# https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
 
 LANGUAGES_DICT = {
     "cs_CZ": "Čeština [BETA]",
@@ -30,6 +30,7 @@ LANGUAGES_DICT = {
     "ro_RO": "Român",
     "ru_RU": "Русский",
     "sk_SK": "Slovenčina [BETA]",
+    "fi_FI": "Suomi [BETA]",
     "sv_SE": "Svenska [BETA]",
     "sq_AL": "Shqip [ALPHA]",
     "tr_TR": "Türkçe [BETA]",
