@@ -5,6 +5,7 @@ import tkinter.font as tk_font
 
 from thonny import get_workbench, ui_utils
 from thonny.common import ValueInfo
+from thonny.languages import tr
 from thonny.ui_utils import TreeFrame
 
 MAX_REPR_LENGTH_IN_GRID = 100
@@ -15,7 +16,7 @@ def format_object_id(object_id):
     if object_id is None:
         return None
     else:
-        return "0x" + hex(object_id)[2:].upper()  # .rjust(8,'0')
+        return "0x" + hex(object_id)[2:]  # .rjust(8,'0')
 
 
 def parse_object_id(object_id_repr):
@@ -23,8 +24,8 @@ def parse_object_id(object_id_repr):
 
 
 class MemoryFrame(TreeFrame):
-    def __init__(self, master, columns):
-        TreeFrame.__init__(self, master, columns)
+    def __init__(self, master, columns, show_statusbar=False):
+        TreeFrame.__init__(self, master, columns, show_statusbar=show_statusbar)
 
         font = tk_font.nametofont("TkDefaultFont").copy()
         font.configure(underline=True)
@@ -34,15 +35,21 @@ class MemoryFrame(TreeFrame):
         self._clear_tree()
 
     def show_selected_object_info(self):
+        object_id = self.get_object_id()
+        if object_id is not None:
+            get_workbench().event_generate("ObjectSelect", object_id=object_id)
+
+    def get_object_id(self):
         iid = self.tree.focus()
         if iid != "":
             # NB! Assuming id is second column!
             id_str = self.tree.item(iid)["values"][1]
             if id_str in ["", None, "None"]:
-                return
+                return None
 
-            object_id = parse_object_id(id_str)
-            get_workbench().event_generate("ObjectSelect", object_id=object_id)
+            return parse_object_id(id_str)
+
+        return None
 
 
 class VariablesFrame(MemoryFrame):
@@ -53,9 +60,9 @@ class VariablesFrame(MemoryFrame):
         self.tree.column("id", width=450, anchor=tk.W, stretch=True)
         self.tree.column("value", width=450, anchor=tk.W, stretch=True)
 
-        self.tree.heading("name", text="Name", anchor=tk.W)
-        self.tree.heading("id", text="Value ID", anchor=tk.W)
-        self.tree.heading("value", text="Value", anchor=tk.W)
+        self.tree.heading("name", text=tr("Name"), anchor=tk.W)
+        self.tree.heading("id", text=tr("Value ID"), anchor=tk.W)
+        self.tree.heading("value", text=tr("Value"), anchor=tk.W)
 
         get_workbench().bind("ShowView", self._update_memory_model, True)
         get_workbench().bind("HideView", self._update_memory_model, True)
