@@ -2,19 +2,22 @@
 
 import datetime
 import platform
+import sys
 import tkinter as tk
 import tkinter.font
-import webbrowser
 from tkinter import ttk
 
 import thonny
 from thonny import get_workbench, ui_utils
-from thonny.misc_utils import get_python_version_string
+from thonny.common import get_python_version_string
+from thonny.languages import tr
 from thonny.ui_utils import CommonDialog
 
 
 class AboutDialog(CommonDialog):
     def __init__(self, master):
+        import webbrowser
+
         super().__init__(master)
 
         main_frame = ttk.Frame(self)
@@ -22,7 +25,7 @@ class AboutDialog(CommonDialog):
         main_frame.rowconfigure(0, weight=1)
         main_frame.columnconfigure(0, weight=1)
 
-        self.title(_("About Thonny"))
+        self.title(tr("About Thonny"))
         self.resizable(height=tk.FALSE, width=tk.FALSE)
         self.protocol("WM_DELETE_WINDOW", self._ok)
 
@@ -66,7 +69,8 @@ class AboutDialog(CommonDialog):
             text=system_desc
             + "\n"
             + "Python "
-            + get_python_version_string()
+            + get_python_version_string(maxsize=sys.maxsize)
+            + "\n"
             + "Tk "
             + ui_utils.get_tk_version_str(),
         )
@@ -74,7 +78,7 @@ class AboutDialog(CommonDialog):
 
         credits_label = ttk.Label(
             main_frame,
-            text=_(
+            text=tr(
                 "Made in\n"
                 + "University of Tartu, Estonia,\n"
                 + "with the help from\n"
@@ -100,7 +104,7 @@ class AboutDialog(CommonDialog):
             text="Copyright (©) "
             + str(datetime.datetime.now().year)
             + " Aivar Annamaa\n"
-            + _(
+            + tr(
                 "This program comes with\n"
                 + "ABSOLUTELY NO WARRANTY!\n"
                 + "It is free software, and you are welcome to\n"
@@ -113,7 +117,7 @@ class AboutDialog(CommonDialog):
         )
         license_label.grid(pady=20)
 
-        ok_button = ttk.Button(main_frame, text="OK", command=self._ok, default="active")
+        ok_button = ttk.Button(main_frame, text=tr("OK"), command=self._ok, default="active")
         ok_button.grid(pady=(0, 15))
         ok_button.focus_set()
 
@@ -137,24 +141,26 @@ def load_plugin() -> None:
         ui_utils.show_dialog(AboutDialog(get_workbench()))
 
     def open_url(url):
+        import webbrowser
+
         # webbrowser.open returns bool, but add_command expects None
         webbrowser.open(url)
 
     get_workbench().add_command(
         "changelog",
         "help",
-        _("Version history"),
+        tr("Version history"),
         lambda: open_url("https://github.com/thonny/thonny/blob/master/CHANGELOG.rst"),
         group=60,
     )
     get_workbench().add_command(
         "issues",
         "help",
-        _("Report problems"),
+        tr("Report problems"),
         lambda: open_url("https://github.com/thonny/thonny/issues/new"),
         group=60,
     )
-    get_workbench().add_command("about", "help", _("About Thonny"), open_about, group=61)
+    get_workbench().add_command("about", "help", tr("About Thonny"), open_about, group=61)
 
     # For Mac
     get_workbench().createcommand("tkAboutDialog", open_about)
