@@ -109,9 +109,7 @@ class Completer(tk.Listbox):
 
     def _show_box(self, completions):
         self.delete(0, self.size())
-        self.insert(
-            0, *[c["name"] + ("=" if c["complete"].endswith("=") else "") for c in completions]
-        )
+        self.insert(0, *[c["name"] for c in completions])
         self.activate(0)
         self.selection_set(0)
 
@@ -165,7 +163,7 @@ class Completer(tk.Listbox):
         return self.winfo_ismapped()
 
     def _insert_completion(self, completion):
-        typed_len = len(completion["name"]) - len(completion["complete"].strip("="))
+        typed_len = len(completion["name"]) - len(completion["complete"])
         typed_prefix = self.text.get("insert-{}c".format(typed_len), "insert")
         get_workbench().event_generate(
             "AutocompleteInsertion",
@@ -278,6 +276,9 @@ class ShellCompleter(Completer):
             # check if the response is relevant for current state
             if msg.source != self._get_prefix():
                 self._close()
+            elif msg.get("error"):
+                self._close()
+                messagebox.showerror("Autocomplete error", msg.error, master=self)
             else:
                 self._present_completions(msg.completions)
 
