@@ -1,18 +1,25 @@
 import os
-from thonny.backend import get_vm, Executor, prepare_hooks, return_execution_result
-import webbrowser
+
+from thonny.plugins.cpython.cpython_backend import (
+    get_backend,
+    Executor,
+    return_execution_result,
+    prepare_hooks,
+)
 
 
 def _cmd_Birdseye(cmd):
-    vm = get_vm()
-    vm.switch_env_to_script_mode(cmd)
-    return vm._execute_file(cmd, BirdsEyeRunner)
+    backend = get_backend()
+    backend.switch_env_to_script_mode(cmd)
+    return backend._execute_file(cmd, BirdsEyeRunner)
 
 
 class BirdsEyeRunner(Executor):
     @return_execution_result
     @prepare_hooks
     def execute_source(self, source, filename, mode, ast_postprocessors):
+        import webbrowser
+
         assert mode == "exec"
         # ignore ast_postprocessors, because birdseye requires source
 
@@ -25,7 +32,6 @@ class BirdsEyeRunner(Executor):
 
         # Following is a trick, which allows importing birdseye in the backends,
         # which doesn't have it installed (provided it is installed for frontend Python)
-        self._vm.load_modules_with_frontend_path(["birdseye.bird"])
         from birdseye.bird import eye
 
         eye.exec_string(source, filename, globs=global_vars, locs=global_vars, deep=True)
@@ -34,4 +40,10 @@ class BirdsEyeRunner(Executor):
 
 
 def load_plugin():
-    get_vm().add_command("Birdseye", _cmd_Birdseye)
+    try:
+        os.environ["OUTDATED_IGNORE"] = "1"
+        # TODO: it would be good to do this here, but it's slow
+        # import birdseye.bird  # need to import at plugin load time, because later it may not be in path
+    except ImportError:
+        pass
+    get_backend().add_command("Birdseye", _cmd_Birdseye)
