@@ -1,7 +1,8 @@
-from thonny.backend import get_vm
 import os.path
 import platform
 
+from thonny.plugins.cpython.cpython_backend import get_backend
+
 local_conf_file = "matplotlibrc"
 user_conf_file1 = os.path.expanduser("~/.config/matplotlib/matplotlibrc")
 user_conf_file2 = os.path.expanduser("~/.matplotlib/matplotlibrc")
@@ -38,5 +39,5 @@ def set_default_backend(matplotlib):
 def load_plugin():
     if platform.system() == "Darwin":
         # https://github.com/thonny/thonny/issues/676
-        vm = get_vm()
-        vm.add_import_handler("matplotlib", set_default_backend)
+        backend = get_backend()
+        backend.add_import_handler("matplotlib", set_default_backend)
