@@ -1,7 +1,8 @@
 from typing import Callable, Dict, Union  # @UnusedImport
 
 from thonny import get_workbench
-from thonny.misc_utils import running_on_linux, running_on_windows, running_on_mac_os
+from thonny.misc_utils import running_on_linux, running_on_mac_os, running_on_windows
+from thonny.ui_utils import ems_to_pixels
 from thonny.workbench import BasicUiThemeSettings, CompoundUiThemeSettings
 
 
@@ -69,7 +70,7 @@ def _menubutton_settings() -> BasicUiThemeSettings:
 
 
 def _paned_window_settings() -> BasicUiThemeSettings:
-    return {"Sash": {"configure": {"sashthickness": scale(10)}}}
+    return {"Sash": {"configure": {"sashthickness": ems_to_pixels(0.6)}}}
 
 
 def _menu_settings() -> BasicUiThemeSettings:
@@ -89,8 +90,14 @@ def _text_settings() -> BasicUiThemeSettings:
     }
 
 
-def _label_settings() -> BasicUiThemeSettings:
-    return {"Url.TLabel": {"configure": {"foreground": "DarkBlue"}}}
+def _link_settings() -> BasicUiThemeSettings:
+    tip_background = "#b8c28d"
+    tip_background = "systemInfoBackground"
+    return {
+        "Url.TLabel": {"configure": {"foreground": "DarkBlue"}},
+        "Tip.TLabel": {"configure": {"background": tip_background, "foreground": "black"}},
+        "Tip.TFrame": {"configure": {"background": tip_background}},
+    }
 
 
 def _button_notebook_settings() -> BasicUiThemeSettings:
@@ -298,7 +305,7 @@ def clam() -> BasicUiThemeSettings:
         },
         "TLabelframe": {"configure": {"labeloutside": True, "labelmargins": [0, 0, 0, scale(4)]}},
         "TProgressbar": {"configure": {"background": frame}},
-        "Sash": {"configure": {"sashthickness": scale(6), "gripcount": 10}},
+        "Sash": {"configure": {"sashthickness": ems_to_pixels(0.6), "gripcount": 10}},
     }
 
 
@@ -433,6 +440,7 @@ def aqua() -> BasicUiThemeSettings:
 
 
 def windows() -> CompoundUiThemeSettings:
+    tip_background = "#bbbbbb"
     return [
         xpnative(),
         _treeview_settings(),
@@ -440,8 +448,12 @@ def windows() -> CompoundUiThemeSettings:
         _paned_window_settings(),
         _menu_settings(),
         _text_settings(),
-        _label_settings(),
+        _link_settings(),
         _button_notebook_settings(),
+        {
+            "Tip.TLabel": {"configure": {"background": tip_background, "foreground": "black"}},
+            "Tip.TFrame": {"configure": {"background": tip_background}},
+        },
         {
             "TNotebook": {
                 "configure": {
@@ -499,12 +511,13 @@ def windows() -> CompoundUiThemeSettings:
                     "borderwidth": scale(1),
                 }
             },
-            "Inactive.ViewTab.TLabel": {"configure": {"font": "UnderlineTkDefaultFont"}},
+            "Inactive.ViewTab.TLabel": {"map": {"relief": [("hover", "raised")]}},
         },
     ]
 
 
 def enhanced_clam() -> CompoundUiThemeSettings:
+    tip_background = "#bab5ab"
     return [
         clam(),
         _treeview_settings(),
@@ -512,7 +525,11 @@ def enhanced_clam() -> CompoundUiThemeSettings:
         _paned_window_settings(),
         _menu_settings(),
         _text_settings(),
-        _label_settings(),
+        _link_settings(),
+        {
+            "Tip.TLabel": {"configure": {"background": tip_background, "foreground": "black"}},
+            "Tip.TFrame": {"configure": {"background": tip_background}},
+        },
         _button_notebook_settings(),
         {
             "ButtonNotebook.Tab": {
@@ -545,6 +562,15 @@ def enhanced_clam() -> CompoundUiThemeSettings:
                     "highlightthickness": scale(1),
                 }
             },
+            "ViewTab.TLabel": {"configure": {"padding": [scale(5), 0]}},
+            "Active.ViewTab.TLabel": {
+                "configure": {
+                    # "font" : "BoldTkDefaultFont",
+                    "relief": "sunken",
+                    "borderwidth": scale(1),
+                }
+            },
+            "Inactive.ViewTab.TLabel": {"map": {"relief": [("hover", "raised")]}},
         },
     ]
 
@@ -559,6 +585,15 @@ def enhanced_aqua() -> CompoundUiThemeSettings:
             "TPanedWindow": {"configure": {"background": "systemDialogBackgroundActive"}},
             "TFrame": {"configure": {"background": "systemDialogBackgroundActive"}},
             "Tab": {"map": {"foreground": [("selected", "white")]}},
+            "ViewTab.TLabel": {"configure": {"padding": [scale(5), 0]}},
+            "Active.ViewTab.TLabel": {
+                "configure": {
+                    # "font" : "BoldTkDefaultFont",
+                    "relief": "sunken",
+                    "borderwidth": scale(1),
+                }
+            },
+            "Inactive.ViewTab.TLabel": {"map": {"relief": [("hover", "raised")]}},
         },
     ]
 
