@@ -1,11 +1,13 @@
+import atexit
 import os.path
-from threading import Thread
+import subprocess
 from tkinter import messagebox
 
-from thonny import get_workbench, get_runner
-import logging
+from thonny import THONNY_USER_DIR, get_runner, get_workbench, running
+from thonny.languages import tr
 
 _server_started = False
+_server_process = None
 
 
 def _start_debug_enabled():
@@ -16,14 +18,30 @@ def _start_debug_enabled():
 
 
 def start_server():
-    try:
-        from birdseye import server
+    global _server_process
 
-        server.app.run(
-            port=get_workbench().get_option("run.birdseye_port"), debug=False, use_reloader=False
-        )
-    except Exception:
-        logging.getLogger("thonny").exception("Problem running Birdseye server")
+    out_err_filename = os.path.join(THONNY_USER_DIR, "birdseye.log")
+    output_file = open(out_err_filename, "w")
+    _server_process = subprocess.Popen(
+        [
+            running.get_interpreter_for_subprocess(),
+            "-m",
+            "birdseye",
+            "-p",
+            str(get_workbench().get_option("run.birdseye_port")),
+        ],
+        stdout=output_file,
+        stderr=output_file,
+    )
+    atexit.register(close_server)
+
+
+def close_server():
+    if _server_process is not None:
+        try:
+            _server_process.kill()
+        except Exception:
+            pass
 
 
 def debug_with_birdseye():
@@ -33,19 +51,20 @@ def debug_with_birdseye():
         import birdseye  # @UnusedImport
     except ImportError:
         if messagebox.askyesno(
-            _("About Birdseye"),
-            _(
+            tr("About Birdseye"),
+            tr(
                 "Birdseye is a Python debugger which needs to be installed separately.\n\n"
                 + "Do you want to open the help page and learn more?"
             ),
+            master=get_workbench(),
         ):
             get_workbench().open_help_topic("birdseye")
 
         return
 
     if not _server_started:
+        start_server()
         _server_started = True
-        Thread(target=start_server, daemon=True).start()
 
     os.environ["BIRDSEYE_PORT"] = str(get_workbench().get_option("run.birdseye_port"))
     get_runner().execute_current("Birdseye")
@@ -61,7 +80,7 @@ def load_plugin():
     get_workbench().add_command(
         "birdseye",
         "run",
-        _("Debug current script (birdseye)"),
+        tr("Debug current script (birdseye)"),
         debug_with_birdseye,
         caption="birdseye",
         tester=_start_debug_enabled,
