@@ -190,7 +190,11 @@ def clean(
                 "indicatorforeground": [
                     ("disabled", "alternate", low_foreground),
                     ("disabled", low_foreground),
-                ]
+                ],
+                "indicatorbackground": [
+                    ("disabled", "alternate", text_background),
+                    ("disabled", text_background),
+                ],
             },
         },
         "TRadiobutton": {
@@ -210,7 +214,9 @@ def clean(
             "map": {"background": [("disabled", frame_background), ("active", high_detail)]},
         },
         "TLabel": {"configure": {"foreground": normal_foreground}},
-        "Url.TLabel": {"configure": {"foreground": high_foreground}},
+        "Url.TLabel": {"configure": {"foreground": normal_foreground}},
+        "Tip.TLabel": {"configure": {"foreground": normal_foreground, "background": low_detail}},
+        "Tip.TFrame": {"configure": {"background": low_detail}},
         "TScale": {
             "configure": {
                 "background": high_detail,
@@ -249,7 +255,7 @@ def clean(
             }
         },
         "Inactive.ViewTab.TLabel": {
-            "configure": {"foreground": normal_foreground, "font": "UnderlineTkDefaultFont"},
+            "configure": {"foreground": normal_foreground},
             "map": {"background": [("hover", high_detail)]},
         },
         "Text": {"configure": {"background": text_background, "foreground": normal_foreground}},
@@ -310,11 +316,13 @@ def load_plugin() -> None:
             low_detail="#404040",
             normal_foreground="#9f9f9f",
             high_foreground="#eeeeee",
-            low_foreground="#595959",
+            low_foreground="#666666",
         ),
         dark_images,
     )
 
+    dark_tip_background = ("#b8c28d",)
+
     get_workbench().add_ui_theme(
         "Clean Dark Green",
         "Enhanced Clam",
@@ -326,7 +334,7 @@ def load_plugin() -> None:
             low_detail="#33402F",
             normal_foreground="#9E9E9E",
             high_foreground="#eeeeee",
-            low_foreground="#485C49",
+            low_foreground="#5a725b",
         ),
         dark_images,
     )
@@ -342,7 +350,7 @@ def load_plugin() -> None:
             low_detail="#2F3640",
             normal_foreground="#9E9E9E",
             high_foreground="#eeeeee",
-            low_foreground="#484A5C",
+            low_foreground="#5a5c72",
         ),
         dark_images,
     )
