@@ -872,7 +872,8 @@ class ToplevelExpressionBox(BaseExpressionBox, tk.Toplevel):
 
         self.resizable(False, False)
         if get_tk_version_info() >= (8, 6, 10) and running_on_mac_os():
-            self.wm_overrideredirect(1)
+            # self.wm_overrideredirect(1) # Tkinter wrapper can give error in 3.9.2
+            self.tk.call("wm", "overrideredirect", self._w, 1)
         self.wm_transient(codeview.winfo_toplevel())
         self.lift()
 
@@ -943,7 +944,7 @@ class DialogVisualizer(CommonDialog, FrameVisualizer):
     def _init_layout_widgets(self, master, frame_info):
         self.main_frame = ttk.Frame(
             self
-        )  # just a backgroud behind padding of main_pw, without this OS X leaves white border
+        )  # just a background behind padding of main_pw, without this OS X leaves white border
         self.main_frame.grid(sticky=tk.NSEW)
         self.rowconfigure(0, weight=1)
         self.columnconfigure(0, weight=1)
