@@ -3,11 +3,13 @@
 import tkinter as tk
 from tkinter import ttk
 
+from _tkinter import TclError
+
 from thonny import get_runner, get_workbench
 from thonny.common import InlineCommand
+from thonny.languages import tr
 from thonny.memory import MAX_REPR_LENGTH_IN_GRID, MemoryFrame, format_object_id, parse_object_id
 from thonny.misc_utils import shorten_repr
-from _tkinter import TclError
 
 
 class HeapView(MemoryFrame):
@@ -17,8 +19,8 @@ class HeapView(MemoryFrame):
         self.tree.column("id", width=100, anchor=tk.W, stretch=False)
         self.tree.column("value", width=150, anchor=tk.W, stretch=True)
 
-        self.tree.heading("id", text="ID", anchor=tk.W)
-        self.tree.heading("value", text="Value", anchor=tk.W)
+        self.tree.heading("id", text=tr("ID"), anchor=tk.W)
+        self.tree.heading("value", text=tr("Value"), anchor=tk.W)
 
         get_workbench().bind("get_heap_response", self._handle_heap_event, True)
 
@@ -32,7 +34,7 @@ class HeapView(MemoryFrame):
         info_icon = get_workbench().get_image("information")
         self.info_label = ttk.Label(
             get_workbench().get_toolbar(),
-            text=_("Heap mode is on.\nClose Heap view to turn it off."),
+            text=tr("Heap mode is on.\nClose Heap view to turn it off."),
             image=info_icon,
             compound="left",
             background="#F4FFBA",
@@ -52,11 +54,12 @@ class HeapView(MemoryFrame):
     def before_show(self):
         self._request_heap_data(even_when_hidden=True)
 
-    def on_select(self, event):
+    def get_object_id(self):
         iid = self.tree.focus()
         if iid != "":
-            object_id = parse_object_id(self.tree.item(iid)["values"][0])
-            get_workbench().event_generate("ObjectSelect", object_id=object_id)
+            return parse_object_id(self.tree.item(iid)["values"][0])
+
+        return None
 
     def _request_heap_data(self, msg=None, even_when_hidden=False):
         if self.winfo_ismapped() or even_when_hidden:
@@ -80,4 +83,4 @@ class HeapView(MemoryFrame):
 
 
 def load_plugin() -> None:
-    get_workbench().add_view(HeapView, _("Heap"), "e")
+    get_workbench().add_view(HeapView, tr("Heap"), "e")
