@@ -1,9 +1,10 @@
 import logging
 import tkinter as tk
-import traceback
 
 from thonny import get_workbench, jedi_utils
 
+logger = logging.getLogger(__name__)
+
 tree = None
 
 
@@ -52,8 +53,8 @@ class BaseNameHighlighter:
                     for pos in positions:
                         start_index, end_index = pos[0], pos[1]
                         self.text.tag_add("matched_name", start_index, end_index)
-            except Exception:
-                logging.exception("Problem when updating name highlighting")
+            except Exception as e:
+                logger.exception("Problem when updating name highlighting", exc_info=e)
 
 
 class VariablesHighlighter(BaseNameHighlighter):
@@ -94,8 +95,8 @@ class VariablesHighlighter(BaseNameHighlighter):
                 else:
                     try:
                         return jedi_utils.get_statement_of_position(c, pos)
-                    except AttributeError:
-                        traceback.print_exc()
+                    except AttributeError as e:
+                        logger.exception("Could not get statement of position", exc_info=e)
         return None
 
     def _is_global_stmt_with_name(self, node, name_str):
@@ -163,9 +164,17 @@ class VariablesHighlighter(BaseNameHighlighter):
 
     def _get_dot_names(self, stmt):
         try:
-            if stmt.children[1].children[0].value == ".":
+            if (
+                hasattr(stmt, "children")
+                and len(stmt.children) >= 2
+                and hasattr(stmt.children[1], "children")
+                and len(stmt.children[1].children) >= 1
+                and hasattr(stmt.children[1].children[0], "value")
+                and stmt.children[1].children[0].value == "."
+            ):
                 return stmt.children[0], stmt.children[1].children[1]
-        except Exception:
+        except Exception as e:
+            logger.exception("_get_dot_names", exc_info=e)
             return ()
         return ()
 
@@ -281,7 +290,7 @@ class VariablesHighlighter(BaseNameHighlighter):
 
 
 class UsagesHighlighter(BaseNameHighlighter):
-    """Script.usages looks tempting method to use for finding variable ocurrences,
+    """Script.usages looks tempting method to use for finding variable occurrences,
     but it only returns last
     assignments to a variable, not really all usages (with Jedi 0.10).
     But it finds attribute usages quite nicely.
@@ -295,8 +304,8 @@ class UsagesHighlighter(BaseNameHighlighter):
         # https://github.com/davidhalter/jedi/issues/897
         from jedi import Script
 
-        script = Script(source + ")", line=line, column=column, path="")
-        usages = script.usages()
+        script = Script(source + ")")
+        usages = script.get_references(line, column, include_builtins=False)
 
         result = {
             (
