@@ -71,6 +71,7 @@ from thonny.common import (
     ValueInfo,
 )
 from thonny.common import ConnectionClosedException
+from thonny.plugins.micropython.connection import MicroPythonConnection
 from thonny.running import EXPECTED_TERMINATION_CODE
 
 ENCODING = "utf-8"
@@ -152,6 +153,15 @@ class MicroPythonBackend(MainBackend, ABC):
         script = self._get_all_helpers()
         self._check_perform_just_in_case_gc()
         self._execute_without_output(script)
+        # self._execute_without_output(
+        #     dedent(
+        #         """
+        #     for key in __thonny_helper.builtins.dir(__thonny_helper.builtins):
+        #         if not key.startswith("__"):
+        #             __thonny_helper.builtins.globals()[key] = None
+        #     """
+        #     ).strip()
+        # )
         self._report_time("prepared helpers")
 
         self._update_cwd()
@@ -200,39 +210,39 @@ class MicroPythonBackend(MainBackend, ABC):
             dedent(
                 """
             class __thonny_helper:
+                import builtins
                 try:
                     import uos as os
-                except ImportError:
+                except builtins.ImportError:
                     import os
                 import sys
-                import builtins
                 
                 # for object inspector
-                inspector_values = dict()
-                @classmethod
+                inspector_values = builtins.dict()
+                @builtins.classmethod
                 def print_repl_value(cls, obj):
                     global _
                     if obj is not None:
-                        cls.builtins.print({start_marker!r} % id(obj), repr(obj), {end_marker!r}, sep='')
+                        cls.builtins.print({start_marker!r} % cls.builtins.id(obj), cls.builtins.repr(obj), {end_marker!r}, sep='')
                         _ = obj
                 
-                @classmethod
+                @builtins.classmethod
                 def print_mgmt_value(cls, obj):
-                    cls.builtins.print({mgmt_start!r}, repr(obj), {mgmt_end!r}, sep='', end='')
+                    cls.builtins.print({mgmt_start!r}, cls.builtins.repr(obj), {mgmt_end!r}, sep='', end='')
                     
-                @staticmethod
-                def repr(obj):
+                @builtins.classmethod
+                def repr(cls, obj):
                     try:
-                        s = repr(obj)
-                        if len(s) > 50:
+                        s = cls.builtins.repr(obj)
+                        if cls.builtins.len(s) > 50:
                             s = s[:50] + "..."
                         return s
-                    except Exception as e:
-                        return "<could not serialize: " + str(e) + ">"
+                    except cls.builtins.Exception as e:
+                        return "<could not serialize: " + __thonny_helper.builtins.str(e) + ">"
                     
-                @classmethod
+                @builtins.classmethod
                 def listdir(cls, x):
-                    if hasattr(cls.os, "listdir"):
+                    if cls.builtins.hasattr(cls.os, "listdir"):
                         return cls.os.listdir(x)
                     else:
                         return [rec[0] for rec in cls.os.ilistdir(x) if rec[0] not in ('.', '..')]
@@ -250,6 +260,9 @@ class MicroPythonBackend(MainBackend, ABC):
     def _get_custom_helpers(self):
         return ""
 
+    def get_connection(self) -> MicroPythonConnection:
+        raise NotImplementedError()
+
     def _sync_time(self):
         raise NotImplementedError()
 
@@ -452,10 +465,10 @@ class MicroPythonBackend(MainBackend, ABC):
                 """
             try:
                 from time import localtime as __thonny_localtime
-                __thonny_helper.print_mgmt_value(tuple(__thonny_localtime(%d)))
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.tuple(__thonny_localtime(%d)))
                 del __thonny_localtime
-            except Exception as e:
-                __thonny_helper.print_mgmt_value(str(e))
+            except __thonny_helper.builtins.Exception as e:
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.str(e))
         """
                 % Y2000_EPOCH_OFFSET
             )
@@ -489,7 +502,38 @@ class MicroPythonBackend(MainBackend, ABC):
         raise NotImplementedError()
 
     def _submit_input(self, cdata: str) -> None:
-        raise NotImplementedError()
+        # TODO: what if there is a previous unused data waiting
+        assert self.get_connection().outgoing_is_empty()
+
+        assert cdata.endswith("\n")
+        if not cdata.endswith("\r\n"):
+            # submission is done with CRLF
+            cdata = cdata[:-1] + "\r\n"
+
+        bdata = cdata.encode(ENCODING)
+        to_be_written = bdata
+        echo = b""
+        with self._interrupt_lock:
+            while to_be_written:
+                block = self._extract_block_without_splitting_chars(to_be_written)
+                self._write(block)
+                # Try to consume the echo
+                echo += self.get_connection().soft_read(len(block), timeout=1)
+                to_be_written = to_be_written[len(block) :]
+
+        if echo.replace(b"\r", b"").replace(b"\n", b"") != bdata.replace(b"\r", b"").replace(
+            b"\n", b""
+        ):
+            if any(ord(c) > 127 for c in cdata):
+                print(
+                    "WARNING: MicroPython ignores non-ascii characters of the input",
+                    file=sys.stderr,
+                )
+            else:
+                # because of autoreload? timing problems? interruption?
+                # Leave it.
+                logging.warning("Unexpected echo. Expected %r, got %r" % (bdata, echo))
+            self._connection.unread(echo)
 
     def send_message(self, msg: MessageFromBackend) -> None:
         if "cwd" not in msg:
@@ -660,7 +704,7 @@ class MicroPythonBackend(MainBackend, ABC):
     def _cmd_get_globals(self, cmd):
         if cmd.module_name == "__main__":
             globs = self._evaluate(
-                "{name : (__thonny_helper.repr(value), id(value)) for (name, value) in globals().items() if not name.startswith('__')}"
+                "{name : (__thonny_helper.repr(value), __thonny_helper.builtins.id(value)) for (name, value) in __thonny_helper.builtins.globals().items() if not name.startswith('__')}"
             )
         else:
             globs = self._evaluate(
@@ -668,9 +712,9 @@ class MicroPythonBackend(MainBackend, ABC):
                     """
                 import %s as __mod_for_globs
                 __thonny_helper.print_mgmt_value(
-                    {name : (__thonny_helper.repr(getattr(__mod_for_globs, name)), 
-                             id(getattr(__mod_for_globs, name)))
-                        in dir(__mod_for_globs) 
+                    {name : (__thonny_helper.repr(__thonny_helper.builtins.getattr(__mod_for_globs, name)), 
+                             __thonny_helper.builtins.id(__thonny_helper.builtins.getattr(__mod_for_globs, name)))
+                        in __thonny_helper.builtins.dir(__mod_for_globs) 
                         if not name.startswith('__')}
                 )
                 del __mod_for_globs
@@ -714,8 +758,8 @@ class MicroPythonBackend(MainBackend, ABC):
         self._execute(
             dedent(
                 """
-                if id(__thonny_helper.object_info) not in __thonny_helper.inspector_values:
-                    __thonny_helper.inspector_values[id(__thonny_helper.object_info)] = __thonny_helper.object_info
+                if __thonny_helper.builtins.id(__thonny_helper.object_info) not in __thonny_helper.inspector_values:
+                    __thonny_helper.inspector_values[__thonny_helper.builtins.id(__thonny_helper.object_info)] = __thonny_helper.object_info
             """
             )
         )
@@ -727,18 +771,18 @@ class MicroPythonBackend(MainBackend, ABC):
         to __thonny_helper.object_info.
 
         Can't leave it in a global object, because when querying globals(),
-        repr(globals()) would cause inifite recursion."""
+        repr(globals()) would cause infinite recursion."""
 
         result = self._evaluate(
             dedent(
                 """
                 for __thonny_helper.object_info in (
-                        list(globals().values()) 
-                        + list(__thonny_helper.inspector_values.values())):
-                    if id(__thonny_helper.object_info) == %d:
+                        __thonny_helper.builtins.list(__thonny_helper.builtins.globals().values()) 
+                        + __thonny_helper.builtins.list(__thonny_helper.inspector_values.values())):
+                    if __thonny_helper.builtins.id(__thonny_helper.object_info) == %d:
                         __thonny_helper.print_mgmt_value({
-                            "repr" : repr(__thonny_helper.object_info),
-                            "type": str(type(__thonny_helper.object_info))
+                            "repr" : __thonny_helper.builtins.repr(__thonny_helper.object_info),
+                            "type": __thonny_helper.builtins.str(__thonny_helper.builtins.type(__thonny_helper.object_info))
                         })
                         break
                 else:
@@ -762,19 +806,19 @@ class MicroPythonBackend(MainBackend, ABC):
                     __thonny_helper.print_mgmt_value(None)
                 else:
                     __thonny_helper.context_children = [
-                         getattr(__thonny_helper.context_value, name)
-                         for name in dir(__thonny_helper.context_value)
+                         __thonny_helper.builtins.getattr(__thonny_helper.context_value, name)
+                         for name in __thonny_helper.builtins.dir(__thonny_helper.context_value)
                     ]
-                    if isinstance(__thonny_helper.context_value, (set, tuple, list)):
-                        __thonny_helper.context_children += list(__thonny_helper.context_value)
-                    elif isinstance(__thonny_helper.context_value, dict):
-                        __thonny_helper.context_children += list(__thonny_helper.context_value.values())
+                    if __thonny_helper.builtins.isinstance(__thonny_helper.context_value, (set, tuple, list)):
+                        __thonny_helper.context_children += __thonny_helper.builtins.list(__thonny_helper.context_value)
+                    elif __thonny_helper.builtins.isinstance(__thonny_helper.context_value, __thonny_helper.builtins.dict):
+                        __thonny_helper.context_children += __thonny_helper.builtins.list(__thonny_helper.context_value.values())
                     
                     for __thonny_helper.object_info in __thonny_helper.context_children:
-                        if id(__thonny_helper.object_info) == %d:
+                        if __thonny_helper.builtins.id(__thonny_helper.object_info) == %d:
                             __thonny_helper.print_mgmt_value({
                                 "repr" : __thonny_helper.repr(__thonny_helper.object_info),
-                                "type": str(type(__thonny_helper.object_info))
+                                "type": __thonny_helper.builtins.str(__thonny_helper.builtins.type(__thonny_helper.object_info))
                             })
                             break
                     else:
@@ -794,9 +838,9 @@ class MicroPythonBackend(MainBackend, ABC):
         """object is given in __thonny_helper.object_info"""
         atts = self._evaluate(
             "{name : ("
-            "   id(getattr(__thonny_helper.object_info, name)),"
-            "    __thonny_helper.repr(getattr(__thonny_helper.object_info, name))"
-            ") for name in dir(__thonny_helper.object_info)}"
+            "   __thonny_helper.builtins.id(__thonny_helper.builtins.getattr(__thonny_helper.object_info, name)),"
+            "    __thonny_helper.repr(__thonny_helper.builtins.getattr(__thonny_helper.object_info, name))"
+            ") for name in __thonny_helper.builtins.dir(__thonny_helper.object_info)}"
         )
         return {
             name: ValueInfo(atts[name][0], atts[name][1])
@@ -808,12 +852,12 @@ class MicroPythonBackend(MainBackend, ABC):
         """object is given in __thonny_helper.object_info"""
         if type_name in ("list", "tuple", "set"):
             items = self._evaluate(
-                "[(id(x), __thonny_helper.repr(x)) for x in __thonny_helper.object_info]"
+                "[(__thonny_helper.builtins.id(x), __thonny_helper.repr(x)) for x in __thonny_helper.object_info]"
             )
             return {"elements": [ValueInfo(x[0], x[1]) for x in items]}
         elif type_name == "dict":
             items = self._evaluate(
-                "[((id(key), __thonny_helper.repr(key)), (id(__thonny_helper.object_info[key]), "
+                "[((__thonny_helper.builtins.id(key), __thonny_helper.repr(key)), (__thonny_helper.builtins.id(__thonny_helper.object_info[key]), "
                 "__thonny_helper.repr(__thonny_helper.object_info[key]))) for key in __thonny_helper.object_info]"
             )
             return {
@@ -955,7 +999,7 @@ class MicroPythonBackend(MainBackend, ABC):
                 """
             try:
                 __thonny_helper.print_mgmt_value(__thonny_helper.os.%s(%r))
-            except Exception:
+            except __thonny_helper.builtins.Exception:
                 __thonny_helper.print_mgmt_value(None)
             """
             )
@@ -1051,12 +1095,12 @@ class MicroPythonBackend(MainBackend, ABC):
                 if "." in prefix:
                     obj, prefix = prefix.rsplit(".", 1)
                     names = self._evaluate(
-                        "dir({obj}) if '{obj}' in locals() or '{obj}' in globals() else []".format(
+                        "__thonny_helper.builtins.dir({obj}) if '{obj}' in __thonny_helper.builtins.locals() or '{obj}' in __thonny_helper.builtins.globals() else []".format(
                             obj=obj
                         )
                     )
                 else:
-                    names = self._evaluate("dir()")
+                    names = self._evaluate("__thonny_helper.builtins.dir()")
             else:
                 names = []
                 prefix = ""
@@ -1081,11 +1125,11 @@ class MicroPythonBackend(MainBackend, ABC):
             def __get_object_atts(obj):
                 result = []
                 errors = []
-                for name in dir(obj):
+                for name in __thonny_helper.builtins.dir(obj):
                     try:
-                        val = getattr(obj, name)
-                        result.append((name, repr(val), repr(type(val))))
-                    except BaseException as e:
+                        val = __thonny_helper.builtins.getattr(obj, name)
+                        result.append((name, __thonny_helper.builtins.repr(val), __thonny_helper.builtins.repr(__thonny_helper.builtins.type(val))))
+                    except __thonny_helper.builtins.BaseException as e:
                         errors.append("Couldn't get attr '%s' from object '%r', Err: %r" % (name, obj, e))
                 return (result, errors)
         """
@@ -1203,15 +1247,15 @@ class MicroPythonBackend(MainBackend, ABC):
                 __thonny_result = {} 
                 try:
                     __thonny_names = __thonny_helper.listdir(%r)
-                except OSError:
+                except __thonny_helper.builtins.OSError:
                     __thonny_helper.print_mgmt_value(None) 
                 else:
                     for __thonny_name in __thonny_names:
                         if not __thonny_name.startswith(".") or %r:
                             try:
                                 __thonny_result[__thonny_name] = __thonny_helper.os.stat(%r + __thonny_name)
-                            except OSError as e:
-                                __thonny_result[__thonny_name] = str(e)
+                            except __thonny_helper.builtins.OSError as e:
+                                __thonny_result[__thonny_name] = __thonny_helper.builtins.str(e)
                     __thonny_helper.print_mgmt_value(__thonny_result)
             """
                 )
@@ -1379,6 +1423,9 @@ class MicroPythonBackend(MainBackend, ABC):
     def _decode(self, data: bytes) -> str:
         return data.decode(encoding="UTF-8", errors="replace")
 
+    def _extract_block_without_splitting_chars(self, source_bytes: bytes) -> bytes:
+        raise NotImplementedError()
+
 
 class ManagementError(RuntimeError):
     def __init__(self, script, out, err):
@@ -1466,6 +1513,14 @@ class ReadOnlyFilesystemError(RuntimeError):
     pass
 
 
+def starts_with_continuation_byte(data):
+    return data and is_continuation_byte(data[0])
+
+
+def is_continuation_byte(byte):
+    return (byte & 0b11000000) == 0b10000000
+
+
 if __name__ == "__main__":
     print(ends_overlap("a", "b"))
     print(ends_overlap(">>>", ">>> "))
