@@ -4,6 +4,7 @@ import logging
 import os
 import queue
 import re
+import sys
 import struct
 import time
 from textwrap import dedent, indent
@@ -31,8 +32,11 @@ from thonny.plugins.micropython.backend import (
     PASTE_MODE_LINE_PREFIX,
     EOT,
     WAIT_OR_CRASH_TIMEOUT,
+    starts_with_continuation_byte,
+    is_continuation_byte,
 )
 from thonny.common import ConnectionFailedException
+from thonny.plugins.micropython.connection import MicroPythonConnection
 from thonny.plugins.micropython.webrepl_connection import (
     WebReplConnection,
     WebreplBinaryMsg,
@@ -154,8 +158,14 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
 
         MicroPythonBackend.__init__(self, clean, args)
 
+    def get_connection(self) -> MicroPythonConnection:
+        return self._connection
+
     def _check_prepare(self):
-        out, err = self._execute("print('__thonny_helper' in dir())", capture_output=True)
+        out, err = self._execute(
+            "__thonny_helper.builtins.print('__thonny_helper' in __thonny_helper.builtins.dir())",
+            capture_output=True,
+        )
         if out.strip() == "True":
             return
 
@@ -167,19 +177,19 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
 
         return dedent(
             """
-            @classmethod
+            @builtins.classmethod
             def getcwd(cls):
-                if hasattr(cls, "getcwd"):
+                if cls.builtins.hasattr(cls, "getcwd"):
                     return cls.os.getcwd()
                 else:
                     # micro:bit
                     return ""
             
-            @classmethod
+            @builtins.classmethod
             def chdir(cls, x):
                 return cls.os.chdir(x)
             
-            @classmethod
+            @builtins.classmethod
             def rmdir(cls, x):
                 return cls.os.rmdir(x)
         """
@@ -233,7 +243,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
         return welcome_text
 
     def _fetch_builtin_modules(self):
-        script = "help('modules')"
+        script = "__thonny_helper.builtins.help('modules')"
         out, err = self._execute(script, capture_output=True)
         if err or not out:
             self._send_error_message(
@@ -280,6 +290,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
             """
             ).format(ts=tuple(now))
         else:
+            # RTC.init is used in PyCom, RTC.datetime is used by the rest
             specific_script = dedent(
                 """
                 from machine import RTC as __thonny_RTC
@@ -287,7 +298,8 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                     __thonny_RTC().datetime({datetime_ts})
                 except:
                     __thonny_RTC().init({init_ts})
-                del __thonny_RTC
+                finally:
+                    del __thonny_RTC
 
             """
             ).format(
@@ -295,7 +307,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                     now.tm_year,
                     now.tm_mon,
                     now.tm_mday,
-                    now.tm_wday + 1,
+                    now.tm_wday,
                     now.tm_hour,
                     now.tm_min,
                     now.tm_sec,
@@ -310,8 +322,8 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
             try:
             %s
                 __thonny_helper.print_mgmt_value(True)
-            except Exception as e:
-                __thonny_helper.print_mgmt_value(str(e))
+            except __thonny_helper.builtins.Exception as e:
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.str(e))
         """
             )
             % indent(specific_script, "    ")
@@ -328,7 +340,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
             specific_script = dedent(
                 """
                 from rtc import RTC as __thonny_RTC
-                __thonny_helper.print_mgmt_value(tuple(__thonny_RTC().datetime)[:6])
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.tuple(__thonny_RTC().datetime)[:6])
                 del __thonny_RTC
                 """
             )
@@ -338,12 +350,12 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                 from machine import RTC as __thonny_RTC
                 try:
                     # now() on some devices also gives weekday, so prefer datetime
-                    __thonny_temp = tuple(__thonny_RTC().datetime())
+                    __thonny_temp = __thonny_helper.builtins.tuple(__thonny_RTC().datetime())
                     # remove weekday from index 3
                     __thonny_helper.print_mgmt_value(__thonny_temp[0:3] + __thonny_temp[4:7])
                     del __thonny_temp
                 except:
-                    __thonny_helper.print_mgmt_value(tuple(__thonny_RTC().now())[:6])
+                    __thonny_helper.print_mgmt_value(__thonny_helper.builtins.tuple(__thonny_RTC().now())[:6])
                 del __thonny_RTC
                 """
             )
@@ -353,8 +365,8 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                 """
             try:
             %s
-            except Exception as e:
-                __thonny_helper.print_mgmt_value(str(e))
+            except __thonny_helper.builtins.Exception as e:
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.str(e))
         """
             )
             % indent(specific_script, "    ")
@@ -369,15 +381,15 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
             try:
                 try:
                     from time import localtime as __thonny_localtime
-                    __thonny_helper.print_mgmt_value(tuple(__thonny_localtime()))
+                    __thonny_helper.print_mgmt_value(__thonny_helper.builtins.tuple(__thonny_localtime()))
                     del __thonny_localtime
                 except:
                     # some CP boards
                     from rtc import RTC as __thonny_RTC
-                    __thonny_helper.print_mgmt_value(tuple(__thonny_RTC().datetime))
+                    __thonny_helper.print_mgmt_value(__thonny_helper.builtins.tuple(__thonny_RTC().datetime))
                     del __thonny_RTC
-            except Exception as e:
-                __thonny_helper.print_mgmt_value(str(e))
+            except __thonny_helper.builtins.Exception as e:
+                __thonny_helper.print_mgmt_value(__thonny_helper.builtins.str(e))
         """
         )
 
@@ -520,32 +532,6 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
     def _write(self, data):
         self._connection.write(data)
 
-    def _submit_input(self, cdata: str) -> None:
-        # TODO: what if there is a previous unused data waiting
-        assert self._connection.outgoing_is_empty()
-
-        assert cdata.endswith("\n")
-        if not cdata.endswith("\r\n"):
-            # submission is done with CRLF
-            cdata = cdata[:-1] + "\r\n"
-
-        bdata = cdata.encode(ENCODING)
-        to_be_written = bdata
-        echo = b""
-        with self._interrupt_lock:
-            while to_be_written:
-                block = self._extract_block_without_splitting_chars(to_be_written)
-                self._write(block)
-                # Try to consume the echo
-                echo += self._connection.soft_read(len(block), timeout=1)
-                to_be_written = to_be_written[len(block) :]
-
-        if echo != bdata:
-            # because of autoreload? timing problems? interruption?
-            # Leave it.
-            logging.warning("Unexpected echo. Expected %r, got %r" % (bdata, echo))
-            self._connection.unread(echo)
-
     def _submit_code(self, script):
         """
         Code is submitted via paste mode, because this provides echo, which can be used as flow control.
@@ -978,59 +964,46 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
         return {"returncode": returncode}
 
     def _cmd_get_fs_info(self, cmd):
-        result = self._evaluate(
-            dedent(
-                """
-            try:
-                from os import statvfs as __thonny_statvfs
-                __thonny_stat = __thonny_statvfs(%r)
+        if self._connected_to_microbit():
+            used = self._evaluate(
+                dedent(
+                    """
+                    __thonny_helper.print_mgmt_value(
+                        __thonny_helper.builtins.sum([__thonny_helper.os.size(name) for name in __thonny_helper.os.listdir()])
+                    )  
+                    """
+                )
+            )
+            return {
+                "total": None,
+                "used": used,
+                "free": None,
+                "comment": "Assuming around 30 kB of storage space for user files.",
+            }
+
+        else:
+            result = self._evaluate(
+                dedent(
+                    """
+                __thonny_stat = __thonny_helper.os.statvfs(%r)
                 __thonny_total = __thonny_stat[2] * __thonny_stat[0]
                 __thonny_free = __thonny_stat[3] * __thonny_stat[0]
-                __thonny_used = __thonny_total - __thonny_free
-                __thonny_sizes = None
-                del __thonny_statvfs
+
+                __thonny_helper.print_mgmt_value({
+                    "total" : __thonny_total,
+                    "used" : __thonny_total - __thonny_free,
+                    "free": __thonny_free,
+                })  
+
                 del __thonny_stat 
-            except ImportError:
-                __thonny_sizes = [__thonny_helper.os.size(name) for name in __thonny_helper.os.listdir()]
-                __thonny_used = None
-                __thonny_total = None
-                __thonny_free = None
-            
-            __thonny_helper.print_mgmt_value({
-                "total" : __thonny_total,
-                "used" : __thonny_used,
-                "free": __thonny_free,
-                "sizes": __thonny_sizes
-            })  
-                
-            del __thonny_total
-            del __thonny_free
-            del __thonny_used
-            del __thonny_sizes
-            """
-            )
-            % cmd.path
-        )
-
-        if result["sizes"] is not None:
-            if self._connected_to_microbit():
-                comment = "Assuming around 30 kB of storage space for user files."
-            else:
-                comment = "Don't know the size of storage space on this device."
-
-            files_total_size = sum(result["sizes"])
-
-            # TODO: compute number of used blocks
-            if files_total_size > 0:
-                comment += "\n\n" + "At least %s of it is used by %d file(s)." % (
-                    sizeof_fmt(files_total_size),
-                    len(result["sizes"]),
+                del __thonny_total
+                del __thonny_free
+                """
                 )
+                % cmd.path
+            )
 
-            result["comment"] = comment
-            del result["sizes"]
-
-        return result
+            return result
 
     def _cmd_upload(self, cmd):
         self._check_sync_time()
@@ -1110,7 +1083,9 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
 
         hex_mode = self._should_hexlify(source_path)
 
-        self._execute_without_output("__thonny_fp = open(%r, 'rb')" % source_path)
+        self._execute_without_output(
+            "__thonny_fp = __thonny_helper.builtins.open(%r, 'rb')" % source_path
+        )
         if hex_mode:
             self._execute_without_output("from binascii import hexlify as __temp_hexlify")
 
@@ -1244,9 +1219,9 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
             try:
                 __thonny_path = '{path}'
                 __thonny_written = 0
-                __thonny_fp = open(__thonny_path, 'wb')
-            except Exception as e:
-                print(str(e))
+                __thonny_fp = __thonny_helper.builtins.open(__thonny_path, 'wb')
+            except __thonny_helper.builtins.Exception as e:
+                __thonny_helper.builtins.print(__thonny_helper.builtins.str(e))
             """
             ).format(path=target_path),
             capture_output=True,
@@ -1274,7 +1249,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                     global __thonny_written
                     __thonny_written += __thonny_fp.write(__thonny_unhex(x))
                     __thonny_fp.flush()
-                    if hasattr(__thonny_helper.os, "sync"):
+                    if __thonny_helper.builtins.hasattr(__thonny_helper.os, "sync"):
                         __thonny_helper.os.sync()
             """
                 )
@@ -1298,7 +1273,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                     global __thonny_written
                     __thonny_written += __thonny_fp.write(x)
                     __thonny_fp.flush()
-                    if hasattr(__thonny_helper.os, "sync"):
+                    if __thonny_helper.builtins.hasattr(__thonny_helper.os, "sync"):
                         __thonny_helper.os.sync()
             """
                 )
@@ -1403,7 +1378,7 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
         self._execute_without_output(
             dedent(
                 """
-            if hasattr(__thonny_helper.os, "sync"):
+            if __thonny_helper.builtins.hasattr(__thonny_helper.os, "sync"):
                 __thonny_helper.os.sync()        
         """
             )
@@ -1457,9 +1432,9 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
                     __thonny_result = __thonny_getmount("/").label
                 finally:
                     del __thonny_getmount
-            except ImportError:
+            except __thonny_helper.builtins.ImportError:
                 __thonny_result = None 
-            except OSError:
+            except __thonny_helper.builtins.OSError:
                 __thonny_result = None 
             
             __thonny_helper.print_mgmt_value(__thonny_result)
@@ -1548,13 +1523,6 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
     def _decode(self, data: bytes) -> str:
         return data.decode(ENCODING, errors="replace")
 
-    def _extract_block_without_splitting_chars(self, source_bytes: bytes) -> bytes:
-        i = self._write_block_size
-        while i > 1 and i < len(source_bytes) and is_continuation_byte(source_bytes[i]):
-            i -= 1
-
-        return source_bytes[:i]
-
     def _get_file_operation_block_size(self):
         # don't forget that the size may be expanded up to 4x where converted to Python
         # bytes literal
@@ -1563,13 +1531,12 @@ class BareMetalMicroPythonBackend(MicroPythonBackend, UploadDownloadMixin):
         else:
             return 1024
 
+    def _extract_block_without_splitting_chars(self, source_bytes: bytes) -> bytes:
+        i = self._write_block_size
+        while i > 1 and i < len(source_bytes) and is_continuation_byte(source_bytes[i]):
+            i -= 1
 
-def starts_with_continuation_byte(data):
-    return data and is_continuation_byte(data[0])
-
-
-def is_continuation_byte(byte):
-    return (byte & 0b11000000) == 0b10000000
+        return source_bytes[:i]
 
 
 class RawPasteNotSupportedError(RuntimeError):
