@@ -23,7 +23,9 @@ class MicroPythonConnection:
         self._read_buffer = bytearray()  # used for unreading and postponing bytes
         self.num_bytes_received = 0
         self.startup_time = time.time()
+        self.unicode_guard = True
         self._error = None
+        self._reader_stopped = False
 
     def soft_read(self, size, timeout=1):
         return self.read(size, timeout, True)
@@ -168,5 +170,13 @@ class MicroPythonConnection:
     def reset_output_buffer(self):
         pass
 
+    def set_unicode_guard(self, value):
+        self.unicode_guard = value
+
+    def stop_reader(self):
+        self._reader_stopped = True
+        self._read_queue = Queue()
+        self._read_buffer = bytearray()
+
     def close(self):
         raise NotImplementedError()
