@@ -24,6 +24,7 @@ from thonny.plugins.micropython.backend import (
 )
 from thonny.plugins.micropython.bare_metal_backend import LF, NORMAL_PROMPT, PASTE_SUBMIT_MODE
 from thonny.common import ConnectionFailedException
+from thonny.plugins.micropython.connection import MicroPythonConnection
 
 FALLBACK_BUILTIN_MODULES = [
     "cmath",
@@ -68,6 +69,9 @@ class UnixMicroPythonBackend(MicroPythonBackend, ABC):
 
         MicroPythonBackend.__init__(self, None, args)
 
+    def get_connection(self) -> MicroPythonConnection:
+        return self._connection
+
     def _resolve_executable(self, executable):
         result = self._which(executable)
         if result:
@@ -103,25 +107,25 @@ class UnixMicroPythonBackend(MicroPythonBackend, ABC):
                 "libc.so.6" if sys.platform == "linux" else "libc.dylib"
             )
             
-            @classmethod
+            @builtins.classmethod
             def check_error(cls, ret):
                 if ret == -1:
-                    raise OSError(cls.os.errno())
+                    raise cls.builtins.OSError(cls.os.errno())
             
             _getcwd = libc.func("s", "getcwd", "si")
-            @classmethod
+            @builtins.classmethod
             def getcwd(cls):
-                buf = bytearray(512)
+                buf = cls.builtins.bytearray(512)
                 return cls._getcwd(buf, 512)
 
             _chdir = libc.func("i", "chdir", "s")
-            @classmethod
+            @builtins.classmethod
             def chdir(cls, dir):
                 r = cls._chdir(dir)
                 cls.check_error(r)
             
             _rmdir = libc.func("i", "rmdir", "s")
-            @classmethod
+            @builtins.classmethod
             def rmdir(cls, name):
                 e = cls._rmdir(name)
                 cls.check_error(e)                                    
@@ -301,30 +305,8 @@ class UnixMicroPythonBackend(MicroPythonBackend, ABC):
         except Exception as e:
             return str(e)
 
-    def _submit_input(self, cdata: str) -> None:
-        # TODO: what if there is a previous unused data waiting
-        assert self._connection.outgoing_is_empty()
-
-        assert cdata.endswith("\n")
-        if not cdata.endswith("\r\n"):
-            # submission is done with CRLF
-            cdata = cdata[:-1] + "\r\n"
-
-        bdata = cdata.encode(ENCODING)
-        to_be_written = bdata
-        echo = b""
-        with self._interrupt_lock:
-            self._write(to_be_written)
-            # Try to consume the echo
-            echo += self._connection.soft_read(len(to_be_written), timeout=1)
-
-        if echo.replace(b"\r", b" ").replace(b"\n", b" ") != bdata.replace(b"\r", b" ").replace(
-            b"\n", b" "
-        ):
-            # because of autoreload? timing problems? interruption?
-            # Leave it.
-            logging.warning("Unexpected echo. Expected %r, got %r" % (bdata, echo))
-            self._connection.unread(echo)
+    def _extract_block_without_splitting_chars(self, source_bytes: bytes) -> bytes:
+        return source_bytes
 
 
 class LocalUnixMicroPythonBackend(UnixMicroPythonBackend):
