@@ -1,14 +1,16 @@
 import ast
 import logging
 import tkinter as tk
-from tkinter import ttk
+from tkinter import ttk, messagebox
 
 import thonny.memory
 from thonny import get_runner, get_workbench, ui_utils
 from thonny.common import InlineCommand
+from thonny.languages import tr
+from thonny.memory import MemoryFrame
 from thonny.misc_utils import shorten_repr
 from thonny.tktextext import TextFrame
-import base64
+from thonny.ui_utils import ems_to_pixels
 
 
 class ObjectInspector(ttk.Frame):
@@ -34,6 +36,7 @@ class ObjectInspector(ttk.Frame):
         get_workbench().bind("get_object_info_response", self._handle_object_info_event, True)
         get_workbench().bind("DebuggerResponse", self._handle_progress_event, True)
         get_workbench().bind("ToplevelResponse", self._handle_progress_event, True)
+        get_workbench().bind("BackendRestart", self._on_backend_restart, True)
 
         # self.demo()
 
@@ -73,16 +76,18 @@ class ObjectInspector(ttk.Frame):
                     self.active_page = page
                     page.grid(row=1, column=0, sticky="nsew", padx=0)
                     tab.configure(style="Active.ViewTab.TLabel")
-                    if self.active_page == self.attributes_page and (
-                        self.object_info is None or not self.object_info.get("attributes")
+                    if (
+                        self.active_page == self.attributes_page
+                        and (self.object_info is None or not self.object_info.get("attributes"))
+                        and self.object_id is not None
                     ):
                         self.request_object_info()
 
             tab.bind("<1>", on_click)
 
         # create_tab(1, "Overview", self.general_page)
-        create_tab(5, "Data", self.content_page)
-        create_tab(6, "Atts", self.attributes_page)
+        create_tab(5, tr("Data"), self.content_page)
+        create_tab(6, tr("Attributes"), self.attributes_page)
 
         def create_navigation_link(col, image_filename, action, tooltip, padx=0):
             button = ttk.Button(
@@ -105,10 +110,10 @@ class ObjectInspector(ttk.Frame):
         self.title_label.bind("<Configure>", configure, True)
 
         self.back_button = create_navigation_link(
-            1, "nav-backward", self.navigate_back, _("Previous object"), (5, 0)
+            1, "nav-backward", self.navigate_back, tr("Previous object"), (5, 0)
         )
         self.forward_button = create_navigation_link(
-            2, "nav-forward", self.navigate_forward, _("Next object")
+            2, "nav-forward", self.navigate_forward, tr("Next object")
         )
         self.back_links = []
         self.forward_links = []
@@ -133,6 +138,8 @@ class ObjectInspector(ttk.Frame):
                 ElementsInspector(self.content_page),
                 DictInspector(self.content_page),
                 ImageInspector(self.content_page),
+                IntInspector(self.content_page),
+                FloatInspector(self.content_page),
                 ReprInspector(self.content_page),  # fallback content inspector
             ]
         )
@@ -161,6 +168,7 @@ class ObjectInspector(ttk.Frame):
         self._show_object_by_id(event.object_id)
 
     def _show_object_by_id(self, object_id, via_navigation=False):
+        assert object_id is not None
 
         if self.winfo_ismapped() and self.object_id != object_id:
             if not via_navigation and self.object_id is not None:
@@ -169,16 +177,25 @@ class ObjectInspector(ttk.Frame):
                 self.back_links.append(self.object_id)
                 del self.forward_links[:]
 
+            context_id = self.object_id
             self.object_id = object_id
             self.set_object_info(None)
             self._set_title("object @ " + thonny.memory.format_object_id(object_id))
-            self.request_object_info()
+            self.request_object_info(context_id=context_id)
+
+    def _on_backend_restart(self, event=None):
+        self.set_object_info(None)
+        self.object_id = None
 
     def _set_title(self, text):
         self.title_label.configure(text=text)
 
     def _handle_object_info_event(self, msg):
         if self.winfo_ismapped():
+            if msg.get("error") and not msg.get("info"):
+                self.set_object_info({"error": msg["error"]})
+                return
+
             if msg.info["id"] == self.object_id:
                 if hasattr(msg, "not_found") and msg.not_found:
                     self.object_id = None
@@ -188,9 +205,10 @@ class ObjectInspector(ttk.Frame):
 
     def _handle_progress_event(self, event):
         if self.object_id is not None:
+            # refresh
             self.request_object_info()
 
-    def request_object_info(self):
+    def request_object_info(self, context_id=None):
         # current width and height of the frame are required for
         # some content providers
         if self.active_page is not None:
@@ -201,7 +219,6 @@ class ObjectInspector(ttk.Frame):
             if frame_width < 5 or frame_height < 5:
                 frame_width = None
                 frame_height = None
-            # print("pa", frame_width, frame_height)
         else:
             frame_width = None
             frame_height = None
@@ -210,6 +227,9 @@ class ObjectInspector(ttk.Frame):
             InlineCommand(
                 "get_object_info",
                 object_id=self.object_id,
+                context_id=context_id,
+                back_links=self.back_links,
+                forward_links=self.forward_links,
                 include_attributes=self.active_page == self.attributes_page,
                 all_attributes=False,
                 frame_width=frame_width,
@@ -235,6 +255,7 @@ class ObjectInspector(ttk.Frame):
                 + thonny.memory.format_object_id(object_info["id"])
             )
             self.attributes_page.update_variables(object_info["attributes"])
+            self.attributes_page.context_id = object_info["id"]
             self.update_type_specific_info(object_info)
 
             # update layout
@@ -261,7 +282,6 @@ class ObjectInspector(ttk.Frame):
                 content_inspector = insp
                 break
 
-        # print("TYPSE", content_inspector)
         if content_inspector != self.current_content_inspector:
             if self.current_content_inspector is not None:
                 self.current_content_inspector.grid_remove()  # TODO: or forget?
@@ -275,10 +295,6 @@ class ObjectInspector(ttk.Frame):
         if self.current_content_inspector is not None:
             self.current_content_inspector.set_object_info(object_info)
 
-    def goto_type(self, event):
-        if self.object_info is not None:
-            get_workbench().event_generate("ObjectSelect", object_id=self.object_info["type_id"])
-
 
 class ContentInspector:
     def __init__(self, master):
@@ -376,7 +392,15 @@ class StringInspector(TextFrame, ContentInspector):
 
     def set_object_info(self, object_info):
         # TODO: don't show too big string
-        content = ast.literal_eval(object_info["repr"])
+        try:
+            content = ast.literal_eval(object_info["repr"])
+        except SyntaxError:
+            try:
+                # can be shortened
+                content = ast.literal_eval(object_info["repr"] + object_info["repr"][0:1])
+            except SyntaxError:
+                content = "<can't show string content>"
+
         line_count_sep = len(content.split("\n"))
         # line_count_term = len(content.splitlines())
         self.text.configure(height=min(line_count_sep, 10))
@@ -390,6 +414,71 @@ class StringInspector(TextFrame, ContentInspector):
         """
 
 
+class IntInspector(TextFrame, ContentInspector):
+    def __init__(self, master):
+        ContentInspector.__init__(self, master)
+        TextFrame.__init__(
+            self, master, read_only=True, horizontal_scrollbar=False, font="TkDefaultFont"
+        )
+
+    def applies_to(self, object_info):
+        return object_info["type"] == repr(int)
+
+    def set_object_info(self, object_info):
+        content = ast.literal_eval(object_info["repr"])
+        self.text.set_content(
+            object_info["repr"]
+            + "\n\n"
+            + "bin: "
+            + bin(content)
+            + "\n"
+            + "oct: "
+            + oct(content)
+            + "\n"
+            + "hex: "
+            + hex(content)
+            + "\n"
+        )
+
+
+class FloatInspector(TextFrame, ContentInspector):
+    def __init__(self, master):
+        ContentInspector.__init__(self, master)
+        TextFrame.__init__(
+            self,
+            master,
+            read_only=True,
+            horizontal_scrollbar=False,
+            wrap="word",
+            font="TkDefaultFont",
+        )
+
+    def applies_to(self, object_info):
+        return object_info["type"] == repr(float)
+
+    def set_object_info(self, object_info):
+        content = object_info["repr"] + "\n\n\n"
+
+        if "as_integer_ratio" in object_info:
+            ratio = object_info["as_integer_ratio"]
+            from decimal import Decimal
+
+            ratio_dec_str = str(Decimal(ratio[0]) / Decimal(ratio[1]))
+
+            if ratio_dec_str != object_info["repr"]:
+                explanation = tr(
+                    "The representation above is an approximate value of this float. "
+                    "The exact stored value is %s which is about %s"
+                )
+
+                content += explanation % (
+                    "\n\n  %d / %d\n\n" % ratio,
+                    "\n\n  %s\n\n" % ratio_dec_str,
+                )
+
+        self.text.set_content(content)
+
+
 class ReprInspector(TextFrame, ContentInspector):
     def __init__(self, master):
         ContentInspector.__init__(self, master)
@@ -419,16 +508,22 @@ class ReprInspector(TextFrame, ContentInspector):
 class ElementsInspector(thonny.memory.MemoryFrame, ContentInspector):
     def __init__(self, master):
         ContentInspector.__init__(self, master)
-        thonny.memory.MemoryFrame.__init__(self, master, ("index", "id", "value"))
+        thonny.memory.MemoryFrame.__init__(
+            self, master, ("index", "id", "value"), show_statusbar=True
+        )
 
         # self.vert_scrollbar.grid_remove()
-        self.tree.column("index", width=40, anchor=tk.W, stretch=False)
+        self.tree.column("index", width=ems_to_pixels(4), anchor=tk.W, stretch=False)
         self.tree.column("id", width=750, anchor=tk.W, stretch=True)
         self.tree.column("value", width=750, anchor=tk.W, stretch=True)
 
-        self.tree.heading("index", text="Index", anchor=tk.W)
-        self.tree.heading("id", text="Value ID", anchor=tk.W)
-        self.tree.heading("value", text="Value", anchor=tk.W)
+        self.tree.heading("index", text=tr("Index"), anchor=tk.W)
+        self.tree.heading("id", text=tr("Value ID"), anchor=tk.W)
+        self.tree.heading("value", text=tr("Value"), anchor=tk.W)
+
+        self.len_label = ttk.Label(self.statusbar, text="", anchor="w")
+        self.len_label.grid(row=0, column=0, sticky="w")
+        self.statusbar.columnconfigure(0, weight=1)
 
         self.elements_have_indices = None
         self.update_memory_model()
@@ -465,6 +560,7 @@ class ElementsInspector(thonny.memory.MemoryFrame, ContentInspector):
 
         self.elements_have_indices = object_info["type"] in (repr(tuple), repr(list))
         self._update_columns()
+        self.context_id = object_info["id"]
 
         self._clear_tree()
         index = 0
@@ -483,30 +579,30 @@ class ElementsInspector(thonny.memory.MemoryFrame, ContentInspector):
             index += 1
 
         count = len(object_info["elements"])
-        self.tree.config(height=min(count, 10))
-
-        """ TODO:
-        label.configure (
-            text=("%d element" if count == 1 else "%d elements") % count
-        )
-        """
+        self.len_label.configure(text=" len: %d" % count)
 
 
 class DictInspector(thonny.memory.MemoryFrame, ContentInspector):
     def __init__(self, master):
         ContentInspector.__init__(self, master)
-        thonny.memory.MemoryFrame.__init__(self, master, ("key_id", "id", "key", "value"))
-        self.configure(border=1)
+        thonny.memory.MemoryFrame.__init__(
+            self, master, ("key_id", "id", "key", "value"), show_statusbar=True
+        )
+        # self.configure(border=1)
         # self.vert_scrollbar.grid_remove()
-        self.tree.column("key_id", width=100, anchor=tk.W, stretch=False)
+        self.tree.column("key_id", width=ems_to_pixels(7), anchor=tk.W, stretch=False)
         self.tree.column("key", width=100, anchor=tk.W, stretch=False)
         self.tree.column("id", width=750, anchor=tk.W, stretch=True)
         self.tree.column("value", width=750, anchor=tk.W, stretch=True)
 
-        self.tree.heading("key_id", text="Key ID", anchor=tk.W)
-        self.tree.heading("key", text="Key", anchor=tk.W)
-        self.tree.heading("id", text="Value ID", anchor=tk.W)
-        self.tree.heading("value", text="Value", anchor=tk.W)
+        self.tree.heading("key_id", text=tr("Key ID"), anchor=tk.W)
+        self.tree.heading("key", text=tr("Key"), anchor=tk.W)
+        self.tree.heading("id", text=tr("Value ID"), anchor=tk.W)
+        self.tree.heading("value", text=tr("Value"), anchor=tk.W)
+
+        self.len_label = ttk.Label(self.statusbar, text="", anchor="w")
+        self.len_label.grid(row=0, column=0, sticky="w")
+        self.statusbar.columnconfigure(0, weight=1)
 
         self.update_memory_model()
 
@@ -528,6 +624,7 @@ class DictInspector(thonny.memory.MemoryFrame, ContentInspector):
 
     def set_object_info(self, object_info):
         assert "entries" in object_info
+        self.context_id = object_info["id"]
 
         self._clear_tree()
         # TODO: don't show too big number of elements
@@ -543,14 +640,7 @@ class DictInspector(thonny.memory.MemoryFrame, ContentInspector):
             )
 
         count = len(object_info["entries"])
-        self.tree.config(height=min(count, 10))
-
-        """ TODO:
-        label.configure (
-            text=("%d entry" if count == 1 else "%d entries") % count
-        )
-        """
-
+        self.len_label.configure(text=" len: %d" % count)
         self.update_memory_model()
 
 
@@ -564,8 +654,9 @@ class ImageInspector(ContentInspector, tk.Frame):
         self.columnconfigure(0, weight=1)
 
     def set_object_info(self, object_info):
-        # print(object_info["image_data"])
         if isinstance(object_info["image_data"], bytes):
+            import base64
+
             data = base64.b64encode(object_info["image_data"])
         elif isinstance(object_info["image_data"], str):
             data = object_info["image_data"]
@@ -596,6 +687,29 @@ class AttributesFrame(thonny.memory.VariablesFrame):
     def on_double_click(self, event):
         self.show_selected_object_info()
 
+    def show_selected_object_info(self):
+        object_id = self.get_object_id()
+        if object_id is None:
+            return
+
+        iid = self.tree.focus()
+        if not iid:
+            return
+        repr_str = self.tree.item(iid)["values"][2]
+
+        if repr_str == "<bound_method>":
+            from thonny.plugins.micropython import MicroPythonProxy
+
+            if isinstance(get_runner().get_backend_proxy(), MicroPythonProxy):
+                messagebox.showinfo(
+                    "Not supported",
+                    "Inspecting bound methods is not supported with MicroPython",
+                    master=self,
+                )
+                return
+
+        get_workbench().event_generate("ObjectSelect", object_id=object_id)
+
 
 def load_plugin() -> None:
-    get_workbench().add_view(ObjectInspector, _("Object inspector"), "se")
+    get_workbench().add_view(ObjectInspector, tr("Object inspector"), "se")
