@@ -4,7 +4,13 @@ import re
 import token
 
 from thonny import assistance
-from thonny.assistance import ErrorHelper, Suggestion, add_error_helper, name_similarity
+from thonny.assistance import (
+    ErrorHelper,
+    Suggestion,
+    add_error_helper,
+    name_similarity,
+    HelperNotSupportedError,
+)
 from thonny.misc_utils import running_on_windows
 
 
@@ -126,7 +132,7 @@ class SyntaxErrorHelper(ErrorHelper):
                         self.tokens[keyword_pos + 1].type not in (token.NEWLINE, tokenize.COMMENT)
                         and t.string == "else"
                     ):
-                        body = "If you want to specify a conditon, then use `elif` or nested `if`."
+                        body = "If you want to specify a condition, then use `elif` or nested `if`."
                     break
 
             i += 1
@@ -420,7 +426,7 @@ class NameErrorHelper(ErrorHelper):
 
         return Suggestion(
             "local-from-global",
-            "Are you trying to acces a local variable outside of the function?",
+            "Are you trying to access a local variable outside of the function?",
             body,
             relevance,
         )
@@ -466,7 +472,11 @@ class AttributeErrorHelper(ErrorHelper):
         super().__init__(error_info)
 
         names = re.findall(r"\'.*?\'", error_info["message"])
-        assert len(names) == 2
+        if len(names) != 2:
+            # Can happen eg. in PGZero
+            # https://github.com/thonny/thonny/issues/1535
+            raise HelperNotSupportedError()
+
         self.type_name = names[0].strip("'")
         self.att_name = names[1].strip("'")
 
