@@ -59,7 +59,13 @@ from thonny.editors import (
     extract_target_path,
 )
 from thonny.languages import tr
-from thonny.misc_utils import construct_cmd_line, running_on_mac_os, running_on_windows
+from thonny.misc_utils import (
+    construct_cmd_line,
+    inside_flatpak,
+    running_on_mac_os,
+    running_on_windows,
+    show_command_not_available_in_flatpak_message,
+)
 from thonny.ui_utils import CommonDialogEx, select_sequence, show_dialog
 from thonny.workdlg import WorkDialog
 
@@ -405,6 +411,10 @@ class Runner:
         self.execute_current("Run")
 
     def _cmd_run_current_script_in_terminal(self) -> None:
+        if inside_flatpak():
+            show_command_not_available_in_flatpak_message()
+            return
+
         filename = get_saved_current_script_filename()
         if not filename:
             return
@@ -1253,8 +1263,8 @@ class BackendTerminatedError(Exception):
 
 
 def is_venv_interpreter_of_current_interpreter(executable):
-    for location in [".", ".."]:
-        cfg_path = os.path.join(location, "pyvenv.cfg")
+    for location in ["..", "."]:
+        cfg_path = os.path.join(os.path.dirname(executable), location, "pyvenv.cfg")
         if os.path.isfile(cfg_path):
             with open(cfg_path) as fp:
                 content = fp.read()
@@ -1262,7 +1272,11 @@ def is_venv_interpreter_of_current_interpreter(executable):
                 if line.replace(" ", "").startswith("home="):
                     _, home = line.split("=", maxsplit=1)
                     home = home.strip()
-                    if os.path.isdir(home) and os.path.samefile(home, sys.prefix):
+                    if os.path.isdir(home) and (
+                        is_same_path(home, sys.prefix)
+                        or is_same_path(home, os.path.join(sys.prefix, "bin"))
+                        or is_same_path(home, os.path.join(sys.prefix, "Scripts"))
+                    ):
                         return True
     return False
 
@@ -1386,7 +1400,6 @@ class InlineCommandDialog(WorkDialog):
         self.response = None
         self._title = title
         self._instructions = instructions
-        self._output_prelude = output_prelude
         self._cmd = cmd
         self.returncode = None
 
@@ -1398,6 +1411,9 @@ class InlineCommandDialog(WorkDialog):
 
         super().__init__(master, autostart=autostart)
 
+        if output_prelude:
+            self.append_text(output_prelude)
+
     def get_title(self):
         return self._title
 
